@@ -148,7 +148,6 @@ def batch_samples(
 def batch_download(
     batch_id: str,
     file_id: Literal["result_file", "multiqc_report", "segmental_calls"],
-    file_name: Optional[str] = Query(...),
     current_user: User = Security(get_current_active_user, scopes=["R"]),
     adapter: StatinaAdapter = Depends(get_nipt_adapter),
 ):
@@ -162,13 +161,13 @@ def batch_download(
     if path.is_dir():
         file_obj = zip_dir(source_dir=file_path)
         response = StreamingResponse(file_obj, media_type="application/octet-stream")
-        response.headers["Content-Disposition"] = f"attachment; filename={file_name}"
+        response.headers["Content-Disposition"] = f"attachment; filename={batch_id}_{file_id}.zip"
         return response
 
     return FileResponse(
         str(path.absolute()),
         media_type="application/octet-stream",
-        filename=file_name or path.name,
+        filename=f"{batch_id}_{file_id}.{path.suffix}",
     )
 
 
@@ -274,10 +273,14 @@ def coverage(
     db_samples: List[DataBaseSample] = statina.crud.find.samples.batch_samples(
         batch_id=batch_id, adapter=adapter
     )
-    samples: List[Sample] = [Sample(**db_sample.dict()) for db_sample in db_samples]
+    validated_samples: List[SampleValidator] = [
+        SampleValidator(**db_sample.dict()) for db_sample in db_samples
+    ]
 
-    scatter_data: Dict[str, CoveragePlotSampleData] = get_scatter_data_for_coverage_plot(samples)
-    box_data: Dict[int, List[float]] = get_box_data_for_coverage_plot(samples)
+    scatter_data: Dict[str, CoveragePlotSampleData] = get_scatter_data_for_coverage_plot(
+        validated_samples
+    )
+    box_data: Dict[int, List[float]] = get_box_data_for_coverage_plot(validated_samples)
     return JSONResponse(
         content=jsonable_encoder(
             dict(
