@@ -1,3 +1,3 @@
-from .batch import Batch
+from .batch import DatabaseBatch
 from .sample import DataBaseSample
 from .user import User
