@@ -1,6 +1,6 @@
 from typing import Literal, Optional, List
 
-from pydantic import BaseModel, validator
+from pydantic import BaseModel, validator, Field
 
 from statina.API.external.constants import (
     SEX_CHROM_ABNORM,
@@ -8,66 +8,75 @@ from statina.API.external.constants import (
     TRISOMI_TRESHOLDS,
     FF_TRESHOLDS,
 )
+from statina.constants import sample_status_options
 from statina.models.database import DataBaseSample
 from statina.models.server.plots.fetal_fraction_sex import x_get_y
 
 
 class SampleWarning(BaseModel):
-    FF_Formatted: Literal["danger", "default", "warning"]
-    Zscore_13: Literal["danger", "default", "warning"]
-    Zscore_18: Literal["danger", "default", "warning"]
-    Zscore_21: Literal["danger", "default", "warning"]
-    FFY: Literal["danger", "default", "warning"]
-    X0: Literal["danger", "default", "warning"]
-    XXX: Literal["danger", "default", "warning"]
+    fetal_fraction_preface: Literal["danger", "default", "warning"]
+    fetal_fraction_y: Literal["danger", "default", "warning"]
+    z_score_13: Literal["danger", "default", "warning"]
+    z_score_18: Literal["danger", "default", "warning"]
+    z_score_21: Literal["danger", "default", "warning"]
+    x0: Literal["danger", "default", "warning"]
+    xxx: Literal["danger", "default", "warning"]
     other: Literal["danger", "default", "warning"]
-    XXY: Literal["danger", "default", "warning"]
-    XYY: Literal["danger", "default", "warning"]
+    xxy: Literal["danger", "default", "warning"]
+    xyy: Literal["danger", "default", "warning"]
 
 
-class Sample(DataBaseSample):
+class Status(BaseModel):
+    status: sample_status_options
+    edited: str
+
+
+class ZScore(BaseModel):
+    z_score_13: str = Field(..., alias="13")
+    z_score_18: str = Field(..., alias="18")
+    z_score_21: str = Field(..., alias="21")
+    z_score_x: str = Field(..., alias="x")
+
+    class Config:
+        allow_population_by_field_name = True
+
+
+class FetalFraction(BaseModel):
+    x: str
+    y: str
+    preface: str
+
+
+class Include(BaseModel):
+    include: Optional[bool] = False
+    edited: Optional[str] = ""
+
+
+class Statuses(BaseModel):
+    status_13: Status = Field(..., alias="13")
+    status_18: Status = Field(..., alias="18")
+    status_21: Status = Field(..., alias="21")
+    status_x0: Status = Field(..., alias="x0")
+    status_xxx: Status = Field(..., alias="xxx")
+    status_xxy: Status = Field(..., alias="xxy")
+    status_xyy: Status = Field(..., alias="xyy")
+
+    class Config:
+        allow_population_by_field_name = True
+
+
+class SampleValidator(DataBaseSample):
     warnings: Optional[SampleWarning]
-    text_warning: Optional[str]
-    status: Optional[str]
+    status_string: Optional[str]
+    status: Optional[Statuses]
+    fetal_fraction: Optional[FetalFraction]
+    z_score: Optional[ZScore]
+    included: Optional[Include]
     sex: Optional[Literal["XX", "XY"]]
-
-    @validator("Zscore_13")
-    def round_zscore_13(cls, v):
-        return round(v, 2)
-
-    @validator("Zscore_18")
-    def round_zscore_18(cls, v):
-        return round(v, 2)
-
-    @validator("Zscore_21")
-    def round_zscore_21(cls, v):
-        return round(v, 2)
-
-    @validator("Zscore_X")
-    def round_zscore_x(cls, v):
-        return round(v, 2)
-
-    @validator("FF_Formatted")
-    def round_ff(cls, v):
-        return round(v, 2)
-
-    @validator("FFX")
-    def round_ffx(cls, v):
-        return round(v, 2)
-
-    @validator("FFY")
-    def round_ffy(cls, v):
-        return round(v, 2)
-
-    @validator("status", always=True)
-    def set_status(cls, v, values: dict) -> str:
-
-        status_list = []
-        for key in TRIS_CHROM_ABNORM + SEX_CHROM_ABNORM:
-            status = values.get(f"status_{key}")
-            if status and status != "Normal":
-                status_list.append(" ".join([status, key]))
-        return ", ".join(status_list)
+    sample_type: str = Field(..., alias="SampleType")
+    qc_flag: str = Field(..., alias="QCFlag")
+    cnv_segment: Optional[str] = Field(..., alias="CNVSegment")
+    text_warning: Optional[str]
 
     @validator("warnings", always=True)
     def set_warnings(cls, v, values: dict) -> SampleWarning:
@@ -77,32 +86,79 @@ class Sample(DataBaseSample):
         fetal_fraction_pf = values.get("FF_Formatted")
         fetal_fraction_y = values.get("FFY")
         fetal_fraction_x = values.get("FFX")
-        sample_warnings["FF_Formatted"]: str = cls.get_ff_preface_warning(
+        sample_warnings["fetal_fraction_preface"]: str = cls.get_ff_preface_warning(
             fetal_fraction_pf=fetal_fraction_pf, fetal_fraction_y=fetal_fraction_y
         )
         sample_warnings["other"]: str = cls.get_other_warning(
             fetal_fraction_y=fetal_fraction_y, fetal_fraction_x=fetal_fraction_x
         )
-        sample_warnings["FFY"]: str = cls.get_ff_y_warning(fetal_fraction_y=fetal_fraction_y)
-        sample_warnings["X0"]: str = cls.get_x0_warning(
+        sample_warnings["fetal_fraction_y"]: str = cls.get_ff_y_warning(
+            fetal_fraction_y=fetal_fraction_y
+        )
+        sample_warnings["x0"]: str = cls.get_x0_warning(
             fetal_fraction_y=fetal_fraction_y, fetal_fraction_x=fetal_fraction_x
         )
-        sample_warnings["XXX"]: str = cls.get_XXX_warning(
+        sample_warnings["xxx"]: str = cls.get_XXX_warning(
             fetal_fraction_y=fetal_fraction_y, fetal_fraction_x=fetal_fraction_x
         )
-        sample_warnings["XYY"]: str = cls.get_XYY_warning(
+        sample_warnings["xyy"]: str = cls.get_XYY_warning(
             fetal_fraction_y=fetal_fraction_y, fetal_fraction_x=fetal_fraction_x
         )
-        sample_warnings["XXY"]: str = cls.get_XXY_warning(
+        sample_warnings["xxy"]: str = cls.get_XXY_warning(
             fetal_fraction_y=fetal_fraction_y, fetal_fraction_x=fetal_fraction_x
         )
+        sample_warnings["z_score_13"]: str = cls.get_tris_warning(
+            z_score=values.get("Zscore_13"), fetal_fraction=fetal_fraction_pf
+        )
+        sample_warnings["z_score_18"]: str = cls.get_tris_warning(
+            z_score=values.get("Zscore_18"), fetal_fraction=fetal_fraction_pf
+        )
+        sample_warnings["z_score_21"]: str = cls.get_tris_warning(
+            z_score=values.get("Zscore_21"), fetal_fraction=fetal_fraction_pf
+        )
+        return SampleWarning(**sample_warnings)
+
+    @validator("fetal_fraction", always=True)
+    def set_fetal_fraction(cls, v, values: dict) -> FetalFraction:
+
+        return FetalFraction(
+            x=round(values["FFX"], 2),
+            y=round(values["FFY"], 2),
+            preface=round(values["FF_Formatted"], 2),
+        )
 
-        for key in ["Zscore_13", "Zscore_18", "Zscore_21"]:
-            z_score = values.get(key)
-            sample_warnings[key]: str = cls.get_tris_warning(
-                z_score=z_score, fetal_fraction=fetal_fraction_pf
+    @validator("z_score", always=True)
+    def set_z_score(cls, v, values: dict) -> ZScore:
+
+        return ZScore(
+            z_score_13=round(values["Zscore_13"], 2),
+            z_score_18=round(values["Zscore_18"], 2),
+            z_score_21=round(values["Zscore_21"], 2),
+            z_score_x=round(values["Zscore_X"], 2),
+        )
+
+    @validator("status_string", always=True)
+    def set_status_string(cls, v, values: dict) -> str:
+
+        status_list = []
+        for key in TRIS_CHROM_ABNORM + SEX_CHROM_ABNORM:
+            status = values.get(f"status_{key}")
+            if status and status != "Normal":
+                status_list.append(" ".join([status, key]))
+        return ", ".join(status_list)
+
+    @validator("status", always=True)
+    def set_status(cls, v, values: dict) -> Statuses:
+
+        statuses_dict = {
+            f"status_{key.lower()}": Status(
+                status=values.get(f"status_{key}"),
+                edited=values.get(f"status_change_{key}"),
             )
-        return SampleWarning(**sample_warnings)
+            for key in TRIS_CHROM_ABNORM + SEX_CHROM_ABNORM
+        }
+
+        return Statuses(**statuses_dict)
 
     @validator("text_warning", always=True)
     def set_text_warning(cls, v, values: dict) -> str:
@@ -120,6 +176,10 @@ class Sample(DataBaseSample):
         fetal_fraction_y = values.get("FFY")
         return "XY" if fetal_fraction_y >= FF_TRESHOLDS["fetal_fraction_y_min"] else "XX"
 
+    @validator("included", always=True)
+    def set_include(cls, v, values: dict) -> Optional[Include]:
+        return Include(include=values["include"], edited=values["change_include_date"])
+
     @classmethod
     def get_tris_warning(cls, z_score: float, fetal_fraction: float) -> str:
         """Get automated trisomy warning, based on preset Zscore thresholds"""
@@ -266,6 +326,29 @@ class Sample(DataBaseSample):
             return "danger"
         return "default"
 
+    class Config:
+        allow_population_by_field_name = True
+
+
+class Sample(BaseModel):
+    sample_type: str
+    qc_flag: str
+    cnv_segment: Optional[str]
+    comment: str
+    sample_id: str
+    batch_id: str
+    warnings: Optional[SampleWarning]
+    text_warning: str
+    sex: Optional[str]
+    sequencing_date: Optional[str]
+    status: Statuses
+    included: Include
+    z_score: ZScore
+    fetal_fraction: FetalFraction
+
+    class Config:
+        allow_population_by_field_name = True
+
 
 class PaginatedSampleResponse(BaseModel):
     document_count: int
